<?php

namespace Drupal\autopost_social\Services;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Drupal\node\NodeInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\autopost_social\SocialPostFactory;
use Drupal\autopost_social\Event\AutopostEvents;
use Drupal\autopost_social\Event\AutopostSocialEvent;

/**
 * Service SocialPost.
 */
class SocialPostService implements EventSubscriberInterface {

  // Use Drupal\Core\StringTranslation\StringTranslationTrait to define
  // $this->t() for string translations in our plugin.
  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[AutopostEvents::POST_SOCIAL] = ['notifyPost'];
    return $events;
  }

  /**
   * Notify Post function.
   *
   * @param \Drupal\autopost_social\Event\AutopostSocialEvent $event
   *   Autopost social event.
   */
  public function notifyPost(AutopostSocialEvent $event) {
    $this->post($event->getProviders(), $event->getNode());
  }

  /**
   * Post Service.
   *
   * @param array $providers
   *   List providers.
   * @param \Drupal\node\NodeInterface $node
   *   Node to post.
   */
  public function post(array $providers, NodeInterface $node) {
    foreach ($providers as $provider) {
      $postInstance = SocialPostFactory::create($provider);
      if (!is_null($postInstance)) {
        if ($postInstance->post($node)) {
          drupal_set_message($this->t('Title published with success'), 'status');
        }
      }
    }
  }

}
